﻿using System;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Base;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                true,                           // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                true                            // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.Order_DetailsTableAdapter().GetData();
     
            this.gridView.BestFitColumns();

            this.gridView.ValidateRow += gridView_ValidateRow;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 행 검증시 처리하기 - gridView_ValidateRow(sender, e)

        /// <summary>
        /// 그리드 뷰 행 검증시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_ValidateRow(object sender, ValidateRowEventArgs e)
        {
            GridView gridView = sender as GridView;

            int unitPrice = Convert.ToInt32(gridView.GetRowCellValue(e.RowHandle, gridView.Columns["UnitPrice"]));
            int quantity  = Convert.ToInt32(gridView.GetRowCellValue(e.RowHandle, gridView.Columns["Quantity" ]));

            if(unitPrice == 0 || quantity == 0)
            {
                e.Valid = false;

                e.ErrorText = "단가와 수량 모두 0 입니다.";
            }
        }

        #endregion
    }
}